@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,13 +29,12 @@
  */
 #include <QWidget>
 class QTimer;
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class TextMessageIndicator : public QWidget
 {
     Q_OBJECT
 public:
-    explicit TextMessageIndicator(QWidget *parent = Q_NULLPTR);
+    explicit TextMessageIndicator(QWidget *parent = nullptr);
 
     enum Icon {
         None,
@@ -47,9 +46,9 @@ public:
     void display(const QString &message, const QString &details = QString(), Icon icon = None, int durationMs = 4000);
 
 protected:
-    bool eventFilter(QObject *obj, QEvent *event) Q_DECL_OVERRIDE;
-    void paintEvent(QPaintEvent *e) Q_DECL_OVERRIDE;
-    void mousePressEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *obj, QEvent *event) override;
+    void paintEvent(QPaintEvent *e) override;
+    void mousePressEvent(QMouseEvent *e) override;
 
 private:
     QRect computeTextRect(const QString &message, int extra_width) const;
@@ -63,4 +62,3 @@ private:
 }
 
 #endif // TEXTMESSAGEINDICATOR_H
-
